==> economynlp-0.0.10.tar.gz: economynlp-0.0.10/economynlp/policy/industrial_policy.py <==
class IndustrialPolicy:
    """
Industrial policy is a set of government measures aimed at promoting the development of a particular industry or sector. The key features of an industrial policy are as follows:

Targeted Industry: Industrial policy typically focuses on specific industries or sectors that the government deems important for economic growth and development.
Government Intervention: Industrial policy involves active government intervention in the market, such as subsidies, tax incentives, regulations, and other forms of support.
Long-Term Perspective: Industrial policy is often a long-term strategy, aimed at developing a sustainable and competitive industry over time.
Coordination: Industrial policy requires coordination among different government agencies, as well as with private sector stakeholders, to ensure the effective implementation of policy measures.    
    """
    def __init__(self, targeted_industry, government_intervention, long_term_perspective, coordination):
        self.targeted_industry = targeted_industry
        self.government_intervention = government_intervention
        self.long_term_perspective = long_term_perspective
        self.coordination = coordination

    def set_targeted_industry(self, targeted_industry):
        self.targeted_industry = targeted_industry

    def set_government_intervention(self, government_intervention):
        self.government_intervention = government_intervention

    def set_long_term_perspective(self, long_term_perspective):
        self.long_term_perspective = long_term_perspective

    def set_coordination(self, coordination):
        self.coordination = coordination

==> economynlp-0.0.15.tar.gz: economynlp-0.0.15/economynlp/policy/industrial_policy.py <==
from economynlp.policy.economic_policy import *

class IndustrialPolicy(EconomicPolicy):
    """
Industrial policy is a set of government measures aimed at promoting the development of a particular industry or sector. The key features of an industrial policy are as follows:

Targeted Industry: Industrial policy typically focuses on specific industries or sectors that the government deems important for economic growth and development.
Government Intervention: Industrial policy involves active government intervention in the market, such as subsidies, tax incentives, regulations, and other forms of support.
Long-Term Perspective: Industrial policy is often a long-term strategy, aimed at developing a sustainable and competitive industry over time.
Coordination: Industrial policy requires coordination among different government agencies, as well as with private sector stakeholders, to ensure the effective implementation of policy measures.    
    """
    def __init__(self,goal, tool, trade_off, political_context,targeted_industry, government_intervention, long_term_perspective, coordination):
        super().__init__(goal, tool, trade_off, political_context)
        self.targeted_industry = targeted_industry
        self.government_intervention = government_intervention
        self.long_term_perspective = long_term_perspective
        self.coordination = coordination

    def set_targeted_industry(self, targeted_industry):
        self.targeted_industry = targeted_industry

    def set_government_intervention(self, government_intervention):
        self.government_intervention = government_intervention

    def set_long_term_perspective(self, long_term_perspective):
        self.long_term_perspective = long_term_perspective

    def set_coordination(self, coordination):
        self.coordination = coordination
